@@ -27,7 +27,7 @@
 
 #include <akonadi/collection.h>
 
-#include <QtGui/QAbstractItemView>
+#include <QAbstractItemView>
 
 namespace Akonadi {
 
@@ -72,10 +72,10 @@ class AKONADI_EXPORT CollectionDialog : public KDialog
   public:
     /* @since 4.6
      */
-    enum CollectionDialogOption
-    {
+    enum CollectionDialogOption {
       None = 0,
-      AllowToCreateNewChildCollection = 1
+      AllowToCreateNewChildCollection = 1,
+      KeepTreeExpanded = 2
     };
 
     Q_DECLARE_FLAGS( CollectionDialogOptions, CollectionDialogOption )
