@@ -71,8 +71,11 @@ static QString containsQueryString( bool doWholeWordSearch, bool matchWordBounda
   if ( doWholeWordSearch ) {
     return QString::fromLatin1( "?v bif:contains \"'%1'\" . " );
   } else {
-    return QString::fromLatin1( "FILTER regex(str(?v), \"%1\", \"i\")" )
-        .arg( matchWordBoundary? QLatin1String( "\\\\b%1" ) : QLatin1String( "%1" ) );
+      if ( matchWordBoundary ) {
+          return QString::fromLatin1( "?v bif:contains \"'%1*'\" . " );
+      } else {
+          return QString::fromLatin1( "FILTER regex(str(?v), \"%1\", \"i\")" );
+      }
   }
 }
 
