@@ -354,9 +354,6 @@ class StandardContactActionManager::Private
               if(mGenericManager->action( Akonadi::StandardActionManager::MoveItemToDialog )) {
                 mGenericManager->action( Akonadi::StandardActionManager::MoveItemToDialog )->setText( i18n( "Move Contact To" ) );
               }
-              if ( mActions.contains( StandardContactActionManager::EditItem ) ) {
-                mActions.value( StandardContactActionManager::EditItem )->setText( i18n( "Edit Contact..." ) );
-              }
             } else if ( mimeType == KABC::ContactGroup::mimeType() ) {
               if(mGenericManager->action( Akonadi::StandardActionManager::CopyItems )) {
                 mGenericManager->setActionText( Akonadi::StandardActionManager::CopyItems,
@@ -658,4 +655,4 @@ void StandardContactActionManager::setCollectionPropertiesPageNames( const QStri
 {
   d->mGenericManager->setCollectionPropertiesPageNames( names );
 }
-#include "standardcontactactionmanager.moc"
+#include "moc_standardcontactactionmanager.cpp"
